@@ -1,26 +1,26 @@
-""" 
+"""
  @file
  @brief This file contains a timeline object, which listens for updates and syncs a libopenshot timeline object
  @author Jonathan Thomas <jonathan@openshot.org>
- 
+
  @section LICENSE
- 
+
  Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
  to the world.
- 
+
  OpenShot Video Editor is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
- 
+
  OpenShot Video Editor is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
- 
+
  You should have received a copy of the GNU General Public License
  along with OpenShot Library.  If not, see <http://www.gnu.org/licenses/>.
  """
@@ -31,7 +31,6 @@ import openshot  # Python module for libopenshot (required video editing module
 from classes.updates import UpdateInterface
 from classes.logger import log
 from classes.app import get_app
-from classes import settings
 
 
 class TimelineSync(UpdateInterface):
@@ -41,7 +40,6 @@ class TimelineSync(UpdateInterface):
         self.app = get_app()
         self.window = window
         project = self.app.project
-        s = settings.get_settings()
 
         # Get some settings from the project
         fps = project.get("fps")
@@ -76,12 +74,16 @@ class TimelineSync(UpdateInterface):
         """ This method is invoked by the UpdateManager each time a change happens (i.e UpdateInterface) """
 
         # Ignore changes that don't affect libopenshot
-        if len(action.key) >= 1 and action.key[0].lower() in ["files", "history", "markers", "layers", "export_path", "import_path", "scale", "profile"]:
+        if len(action.key) >= 1 and action.key[0].lower() in ["files", "history", "markers",
+                                                              "layers", "scale", "profile"]:
             return
 
-        # Pass the change to the libopenshot timeline
         try:
             if action.type == "load":
+                # Clear any existing clips & effects (free memory)
+                self.timeline.Close()
+                self.timeline.Clear()
+
                 # This JSON is initially loaded to libopenshot to update the timeline
                 self.timeline.SetJson(action.json(only_value=True))
                 self.timeline.Open()  # Re-Open the Timeline reader
@@ -89,6 +91,9 @@ class TimelineSync(UpdateInterface):
                 # The timeline's profile changed, so update all clips
                 self.timeline.ApplyMapperToClips()
 
+                # Always seek back to frame 1
+                self.window.SeekSignal.emit(1)
+
                 # Refresh current frame (since the entire timeline was updated)
                 self.window.refreshFrameSignal.emit()
 
@@ -97,7 +102,8 @@ class TimelineSync(UpdateInterface):
                 self.timeline.ApplyJsonDiff(action.json(is_array=True))
 
         except Exception as e:
-            log.info("Error applying JSON to timeline object in libopenshot: %s. %s" % (e, action.json(is_array=True)))
+            log.info("Error applying JSON to timeline object in libopenshot: %s. %s" %
+                     (e, action.json(is_array=True)))
 
     def MaxSizeChangedCB(self, new_size):
         """Callback for max sized change (i.e. max size of video widget)"""
@@ -110,8 +116,9 @@ class TimelineSync(UpdateInterface):
         # Clear timeline preview cache (since our video size has changed)
         self.timeline.ClearAllCache()
 
-        # Set new max video size (Based on preview widget size)
-        self.timeline.SetMaxSize(new_size.width(), new_size.height())
+        # Set new max video size (Based on preview widget size and display scaling)
+        scale = self.window.devicePixelRatioF()
+        self.timeline.SetMaxSize(round(new_size.width() * scale), round(new_size.height() * scale))
 
         # Refresh current frame (since the entire timeline was updated)
         self.window.refreshFrameSignal.emit()
