@@ -1,12 +1,12 @@
 #!/usr/bin/python3
-""" 
+"""
  @file
  @brief This file updates the OpenShot.POT (language translation template) by scanning all source files.
  @author Jonathan Thomas <jonathan@openshot.org>
- 
+
  This file helps you generate the POT file that contains all of the translatable
  strings / text in OpenShot.  Because some of our text is in custom XML files,
- the xgettext command can't correctly generate the POT file.  Thus... the 
+ the xgettext command can't correctly generate the POT file.  Thus... the
  existence of this file. =)
 
  Command to create the individual language PO files (Ascii files)
@@ -28,23 +28,23 @@
        $ msgcat ~/openshot/locale/OpenShot/OpenShot_source.pot ~/openshot/openshot/locale/OpenShot/OpenShot_glade.pot -o ~/openshot/main/locale/OpenShot/OpenShot.pot
 
  @section LICENSE
- 
+
  Copyright (c) 2008-2018 OpenShot Studios, LLC
  (http://www.openshotstudios.com). This file is part of
  OpenShot Video Editor (http://www.openshot.org), an open-source project
  dedicated to delivering high quality video editing and animation solutions
  to the world.
- 
+
  OpenShot Video Editor is free software: you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation, either version 3 of the License, or
  (at your option) any later version.
- 
+
  OpenShot Video Editor is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
- 
+
  You should have received a copy of the GNU General Public License
  along with OpenShot Library.  If not, see <http://www.gnu.org/licenses/>.
  """
@@ -54,8 +54,15 @@ import datetime
 import os
 import subprocess
 import sys
-import xml.dom.minidom as xml
+import re
 import json
+
+# Try to get the security-patched XML functions from defusedxml
+try:
+  from defusedxml import minidom as xml
+except ImportError:
+  from xml.dom import minidom as xml
+
 import openshot
 
 # Get the absolute path of this project
@@ -65,6 +72,7 @@ if path not in sys.path:
 
 import classes.info as info
 from classes.logger import log
+from classes.effect_init import effect_options
 
 # get the path of the main OpenShot folder
 language_folder_path = os.path.dirname(os.path.abspath(__file__))
@@ -183,12 +191,22 @@ for object in objects:
     # Loop through props
     for key in props.keys():
         object = props[key]
-        if "name" in object.keys():
+        if "name" in object:
             effects_text[object["name"]] = "libopenshot (Clip Properties)"
-        if "choices" in object.keys():
+        if "choices" in object:
             for choice in object["choices"]:
                 effects_text[choice["name"]] = "libopenshot (Clip Properties)"
 
+# Append Effect Init Data
+# Loop through props
+for effect in effect_options:
+    for param in effect_options[effect]:
+        if "title" in param:
+            effects_text[param["title"]] = "effect_init (Effect parameter for %s)" % effect
+        if "values" in param:
+            for value in param["values"]:
+                effects_text[value["name"]] = "effect_init (Effect parameter for %s)" % effect
+
 # Append Effect Meta Data
 e = openshot.EffectInfo()
 props = json.loads(e.Json())
@@ -200,7 +218,25 @@ for effect in props:
     if "description" in effect:
         effects_text[effect["description"]] = "libopenshot (Effect Metadata)"
 
+# Append Emoji Data
+emoji_text = { "translator-credits": "Translator credits to be translated by LaunchPad" }
+emoji_metadata_path = os.path.join(info.PATH, "emojis", "data", "openmoji-optimized.json")
+emoji_ignore_keys = ("Keyboard", "Sunset")
+with open(emoji_metadata_path, 'r', encoding="utf-8") as f:
+    emoji_metadata = json.load(f)
+
+    # Loop through props
+    for filename, emoji in emoji_metadata.items():
+        emoji_name = emoji["annotation"].capitalize()
+        emoji_group = emoji["group"].split('-')[0].capitalize()
+        if "annotation" in emoji and emoji_name not in emoji_ignore_keys:
+            emoji_text[emoji_name] = "Emoji Metadata (Displayed Name)"
+        if "group" in emoji and emoji_group not in effects_text and emoji_group not in emoji_ignore_keys:
+            emoji_text[emoji_group] = "Emoji Metadata (Group Filter name)"
+
 # Loop through the Blender XML
+blender_text = { "translator-credits": "Translator credits to be translated by LaunchPad" }
+blender_ignore_keys = ("Title", "Alpha", "Blur")
 for file in os.listdir(blender_path):
     if os.path.isfile(os.path.join(blender_path, file)):
         # load xml effect file
@@ -208,7 +244,9 @@ for file in os.listdir(blender_path):
         xmldoc = xml.parse(os.path.join(blender_path, file))
 
         # add text to list
-        effects_text[xmldoc.getElementsByTagName("title")[0].childNodes[0].data] = full_file_path
+        translation_key = xmldoc.getElementsByTagName("title")[0].childNodes[0].data
+        if translation_key not in blender_ignore_keys:
+            blender_text[translation_key] = full_file_path
 
         # get params
         params = xmldoc.getElementsByTagName("param")
@@ -216,7 +254,9 @@ for file in os.listdir(blender_path):
         # Loop through params
         for param in params:
             if param.attributes["title"]:
-                effects_text[param.attributes["title"].value] = full_file_path
+                translation_key = param.attributes["title"].value
+                if translation_key not in blender_ignore_keys:
+                    blender_text[param.attributes["title"].value] = full_file_path
 
 # Loop through the Export Settings XML
 export_text = {}
@@ -243,9 +283,14 @@ for setting in settings:
         if setting["category"] not in category_names:
             export_text[setting["category"]] = "Settings Category for %s" % setting["category"]
             category_names.append(setting["category"])
+        if "translate_values" in setting and setting.get("translate_values"):
+            # Add translatable dropdown keys
+            for value in setting.get("values", []):
+                export_text[value["name"]] = "Settings for %s" % setting["setting"]
 
 # Loop through transitions and add to POT file
-transitions_text = {}
+transitions_text = { "translator-credits": "Translator credits to be translated by LaunchPad" }
+transitions_ignore_keys = ("Common", "Fade")
 for file in os.listdir(transitions_path):
     # load xml export file
     full_file_path = os.path.join(transitions_path, file)
@@ -255,13 +300,14 @@ for file in os.listdir(transitions_path):
     name = fileBaseName.replace("_", " ").capitalize()
 
     # add text to list
-    transitions_text[name] = full_file_path
+    if name not in transitions_ignore_keys:
+        transitions_text[name] = full_file_path
 
     # Look in sub-folders
     for sub_file in os.listdir(full_file_path):
         # load xml export file
         full_subfile_path = os.path.join(full_file_path, sub_file)
-        (fileBaseName, fileExtension) = os.path.splitext(sub_file)
+        fileBaseName = os.path.splitext(sub_file)[0]
 
         # split the name into parts (looking for a number)
         suffix_number = None
@@ -277,13 +323,14 @@ for file in os.listdir(transitions_path):
             name = name.replace(suffix_number, "%s")
 
         # add text to list
-        transitions_text[name] = full_subfile_path
+        if name not in transitions_ignore_keys:
+            transitions_text[name] = full_subfile_path
 
 # Loop through titles and add to POT file
 for sub_file in os.listdir(titles_path):
     # load xml export file
     full_subfile_path = os.path.join(titles_path, sub_file)
-    (fileBaseName, fileExtension) = os.path.splitext(sub_file)
+    fileBaseName = os.path.splitext(sub_file)[0]
 
     # split the name into parts (looking for a number)
     suffix_number = None
@@ -327,8 +374,12 @@ header_text = header_text + '"Content-Type: text/plain; charset=UTF-8\\n"\n'
 header_text = header_text + '"Content-Transfer-Encoding: 8bit\\n"\n'
 
 # Create POT files for the custom text (from our XML files)
-temp_files = [['OpenShot_effects.pot', effects_text], ['OpenShot_export.pot', export_text],
-              ['OpenShot_transitions.pot', transitions_text]]
+temp_files = [['OpenShot_effects.pot', effects_text],
+              ['OpenShot_export.pot', export_text],
+              ['OpenShot_transitions.pot', transitions_text],
+              ['OpenShot_emojis.pot', emoji_text],
+              ['OpenShot_blender.pot', blender_text]
+              ]
 for temp_file, text_dict in temp_files:
     f = open(temp_file, "w")
 
@@ -351,8 +402,8 @@ log.info(" Combine all temp POT files using msgcat command ")
 log.info(" (this removes dupes) ")
 log.info("-----------------------------------------------------")
 
-temp_files = ['OpenShot_source.pot', 'OpenShot_glade.pot', 'OpenShot_effects.pot', 'OpenShot_export.pot',
-              'OpenShot_transitions.pot', 'OpenShot_QtUi.pot']
+temp_files = ['OpenShot_source.pot', 'OpenShot_glade.pot', 'OpenShot_effects.pot',
+              'OpenShot_export.pot', 'OpenShot_QtUi.pot']
 command = "msgcat"
 for temp_file in temp_files:
     # append files
@@ -381,6 +432,21 @@ final = open(os.path.join(language_folder_path, "OpenShot", "OpenShot.pot"), "w"
 final.write(header_text)
 final.write("\n")
 
+# Move transitions POT file to final location
+if os.path.exists(os.path.join(language_folder_path, "OpenShot_transitions.pot")):
+    os.rename(os.path.join(language_folder_path, "OpenShot_transitions.pot"),
+              os.path.join(language_folder_path, "OpenShot", "OpenShot_transitions.pot"))
+
+# Move emoji POT file to final location
+if os.path.exists(os.path.join(language_folder_path, "OpenShot_emojis.pot")):
+    os.rename(os.path.join(language_folder_path, "OpenShot_emojis.pot"),
+              os.path.join(language_folder_path, "OpenShot", "OpenShot_emojis.pot"))
+
+# Move blender POT file to final location
+if os.path.exists(os.path.join(language_folder_path, "OpenShot_blender.pot")):
+    os.rename(os.path.join(language_folder_path, "OpenShot_blender.pot"),
+              os.path.join(language_folder_path, "OpenShot", "OpenShot_blender.pot"))
+
 # Trim the beginning off of each POT file
 start_pos = entire_source.find("#: ")
 trimmed_source = entire_source[start_pos:]
@@ -408,4 +474,25 @@ for temp_file_name in temp_files:
 log.info("-----------------------------------------------------")
 log.info(" The OpenShot.pot file has been successfully created ")
 log.info(" with all text in OpenShot.")
+log.info("")
+log.info(" Checking for duplicate keys...")
 log.info("-----------------------------------------------------")
+
+# Find any duplicate translations between our 4 template files
+# If these duplicates are translated differently, we will end up
+# with conflicts, and both translations will be combined incorrectly
+all_strings = {}
+
+for pot_file in [
+    'OpenShot.pot',
+    'OpenShot_transitions.pot',
+    'OpenShot_blender.pot',
+    'OpenShot_emojis.pot',
+]:
+    with open(os.path.join(language_folder_path, "OpenShot", pot_file)) as f:
+        data = f.read()
+        for key in re.findall('^msgid \"(.*)\"', data, re.MULTILINE):
+            if key not in all_strings:
+                all_strings[key] = "%s | %s" % (key, pot_file)
+            elif key and key not in ('translator-credits', ):
+                log.info(' ERROR: Duplicate key found: %s::%s' % (pot_file, all_strings[key]))
