@@ -29,6 +29,7 @@ from PyQt5.QtCore import Qt, QSize, QPoint
 from PyQt5.QtGui import QDrag
 from PyQt5.QtWidgets import QTreeView, QAbstractItemView, QMenu, QSizePolicy
 
+from classes import info
 from classes.app import get_app
 from classes.logger import log
 
@@ -80,6 +81,8 @@ class EffectsTreeView(QTreeView):
             # Only execute when the treeview is active
             self.hideColumn(3)
             self.hideColumn(4)
+            self.setColumnWidth(0, 80)
+        self.sortByColumn(0, Qt.AscendingOrder)
 
     def __init__(self, model):
         # Invoke parent init
@@ -103,9 +106,10 @@ class EffectsTreeView(QTreeView):
         self.setSelectionMode(QAbstractItemView.SingleSelection)
         self.setSelectionBehavior(QAbstractItemView.SelectRows)
         self.setSelectionModel(self.effects_model.selection_model)
+        self.setSortingEnabled(True)
 
         # Setup header columns
-        self.setIconSize(QSize(75, 62))
+        self.setIconSize(info.TREE_ICON_SIZE)
         self.setIndentation(0)
         self.setSizePolicy(QSizePolicy.Expanding, QSizePolicy.Expanding)
         self.setWordWrap(True)
